<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Базовий завантажувач</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Отримати список</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>URL-адреса:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Форматування</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Розширення</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Роздільність</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примітка</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Плагін:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Вставити вміст буфера</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Нещодавно використані</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Поточноий параметр завантаження</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Пакетний завантажувач</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Мініатюра</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>URL для завантаження</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Вставити URL із буфера</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Моніторити URL у буфері</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Додати URL до списку</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Встановити</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Завантажувач плейлистів</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Параметри завантаження:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Час початку (HH:MM:SS):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Час закінчення (HH:MM:SS):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Глави (через кому):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Розділити по розділах</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Приховати</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>URL плейлиста:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Очистити внутрішній архівний файл</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Використовувати внутрішній архівний файл</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Бібліотека</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Вище</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Оновити</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Відкрити папку</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Додому</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Загальні параметри</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Показувати значок у треї</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Автозбереження списку незавантажених медіа</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>Приховувати завантажені</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Скинути параметри до початкових</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Скидання</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Параметри шаблонів</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Шлях завантаження</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Вибрати мову</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>Використовувати налаштування проксі</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>Отримати налаштування проксі з оточення</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>Без проксі</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Параметри плагіна за замовчуванням</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Параметри списку:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Підписки</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Ім&apos;я UI</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Увімкнути вкладку &apos;Бібліотека&apos;</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>Максимум одночасних завантажень</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Кодування тексту заголовків</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>Поточна версія та автооновлення</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>Показати поточну та доступну версії</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>Показати поточну версію</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>Нічого не робити</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>Дії після старту</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Плагін</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>За замовчуванням</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Новий рядок</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Менеджер адрес</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Параметри завантаження</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Прив&apos;язка URL до плагіна</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Фільтр URL</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>Налаштування проксі</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>Використовувати системні налаштування проксі</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>Ручне налаштування проксі
Приклад 1: 192.168.93.89: 8080
Приклад 2: ${gateway}:8080</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation>Відтворити завантажені медіа</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation>Введіть URL-програвач або кілька URL, розділених пробілом або новим рядком</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Перейменувати файл</translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation>Відкрити папку завантажень</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation>Відкрити папку з темою</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation>Відкрити папку розширень</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation>Хочете скинути ці параметри на значення за замовчуванням?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ні</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Так</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Ім&apos;я веб-браузера для отримання куків</translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation>Тема (необхідний перезапуск)</translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation>Переключити (ім&apos;я браузера - шлях до файлу куків)</translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation>Показувати метадані в пакетному завантажувачі</translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation>Автоматично завантажувати додане у Пакетному завантажувачі</translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation>Повідомити про закінчення завантаження</translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation>Повідомити після закінчення всіх завантажень</translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation>Налаштування плагінів</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Розширення</translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation>Видалити розширення</translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation>Оновити розширення</translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation>Додати розширення</translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation>Відкрити папку бінарників</translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation>Відкрити папку розширень</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>Шаблони налаштувань %1</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Ім&apos;я файлу з розширенням &apos;.txt&apos; збереже лише URL-адреси</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>Приховати рядок</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>Показати всі приховані рядки</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>Не вдалося запустити виконуваний файл %1</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копіювати URL</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>Відкрити URL у %1</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>Копіювати URL %1</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Зберегти список у файл</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Відповіді на</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Зберегти субтитри у файл</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Плагін:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Отримати список із файлу</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Параметри шаблонів</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Відкрити папку завантаження</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>Сторінка проекту</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Авторське право</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Ліцензія</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Електронна пошта</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Версія Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Ця програма є безкоштовним ПЗ; ви можете розповсюджувати його та/або змінювати відповідно до умов GNU General Public License, опублікованої Free Software Foundation; або версією 2 цієї ліцензії, та (на ваш вибір) будь-якою пізнішою версією.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Ця програма поширюється з надією, що вона буде корисною, але БЕЗ ЖОДНИХ ГАРАНТІЙ; навіть без прихованої гарантії ПРИДАТНОСТІ ДЛЯ ПРОДАЖУ чи ПРИДАТНОСТІ ДЛЯ ПЕВНОЇ МЕТИ. Див. Ліцензію GNU General Public License для отримання детальнішої інформації.</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Англійська</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Арабська</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Іспанська</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Італійська</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>Китайська</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>Нідерландська</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Німецька</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>Польська</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Португальська</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>Російська</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>Турецька</translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation>Українська</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>Французька</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>Шведська</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>Японська</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Помилка, не вдалося знайти виконуваний файл для серверної частини &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Для плагіна &quot;%1&quot; потрібно принаймні &quot;%2&quot; версія Media Downloader</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Щоб вимкнути ці перевірки, зробіть таке:-</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Перейдіть на вкладку &quot;Налаштування&quot;.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Перейдіть на суб-вкладку &quot;Загальні параметри&quot;.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. Натисніть &quot;Дії під час старту&quot;.</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. Виберіть &quot;Нічого не робити&quot;.</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>Запуск у портативному режимі</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>Запуск у режимі встановлення</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>Шлях завантаження: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>Шлях до даних програми: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>Встановлення адреси проксі: %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>Скидання адреси проксі</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Помилка, не вдалося проаналізувати конфігураційний файл &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Неможливо завантажити плагін</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Не вдалося знайти виконуваний файл &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Не вдалося знайти виконуваний файл python3 для серверної частини &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Сталася помилка мережі</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>Url не підтримується</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Завантаження скасовано</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Код помилки</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>Помилка завантаження не вдалося запустити плагін</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Помилка завантаження, збій плагіна</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Форматування</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Розширення</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Роздільність</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Розмір</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примітка</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Неможливо відкрити файл для запису</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Неможливо відкрити файл для читання</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Минуло часу:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Не вдалося знайти інформацію про версію, переконайтеся, що &quot;%1&quot; встановлено та працює правильно</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Знайдена версія</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>Неможливо відкрити шлях для запису: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Не вдалося витягнути</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>Мережа не відповідає %1 сек.</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Неможливо завантажити, не вдається створити шлях: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>Проблема не вдалося видалити папку: %1</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>Не вдалося знайти виконуваний файл &quot;bsdtar.exe&quot;</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Неможливо завантажити</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Не вдалося проаналізувати JSON-файл з github</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Завантажується</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Місце призначення</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Оновлення завершено, перезапустіть, щоб використовувати нову версію</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation>Захищений канал Windows</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Файл не знайдено</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Завантаження завершено</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Розпакування архіву: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Обробка</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Завантаження завершено</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Скинути папку завантаження за замовчуванням</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Постобробка</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Форсувати завантаження</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Показати вікно журналу</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Дата розміщення:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Тривалість:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Назва субтитрів</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Параметри завантаження</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Додати параметри завантаження</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Час завантаження</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Завантажити розділи</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Розділити по розділах</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Медіа вже в архіві</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Темна</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Залишилося часу</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Завантажений</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>%1 вже завантажено</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Це може тривати багато часу</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Швидкість:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>Є оновлення для %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>Нова версія %1, оновлення</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>Перевірка встановленої версії %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>Ваша версія: %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>Нова версія: %1</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Оновіть %1 Принаймні до версії %2</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>Запитаний формат недоступний</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>Введено неправильну URL</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>Тільки найкраще доступне аудіо</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>Тільки найкраще доступне аудіо (MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>Найкраще доступне аудіо та відео</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>Краще аудіо з роздільністю відео %1</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>Увага: Пропуск вмісту буфера обміну</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>Спочатку папки</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>Упорядкувати за зростанням</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>Упорядкувати за датою</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>Упорядкувати на ім&apos;я</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>Упорядкувати за спаданням</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Фільтр</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>Немає фільтра</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>Інші сайти</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>Витягнути аудіо</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>Витягнути аудіо як MP3</translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>Тільки найкраще доступне аудіо + мініатюра</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>Youtube</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>Автооновлення вимкнено для %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>Нова версія %1, автооновлення вимкнено</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>Автор: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>Кількість лайків: %1</translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation>Корейська</translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation>Увійдіть, щоб підтвердити, що ви не бот</translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation>Показати/приховати елементи управління</translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation>Об&apos;єднання аудіо та відео</translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation>Перепакування відео</translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation>Грецька</translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation>Системна</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Світла</translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation>Не вдалося перейменувати</translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation>Завершено: %1, Виконується: %2, Не розпочато: %3, Успішно: %4, Не вдалося: %5, Скасовано: %6</translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation>Зупинено, медіа вже є в архіві</translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation>Болгарська</translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation>Відкрити URL у %2</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Програвач за замовчуванням</translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation>Увага, нічого не завантажено</translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation>Завантаження скасовано, URL-програвачі не допускаються на цій вкладці</translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation>Завантаження скасовано, не виконано умову</translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation>Помилка завантаження, невідома причина</translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation>Помилка завантаження, проблема з мережею</translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Перейменування &quot;%1&quot; на &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation>Не вдалося перейменувати: %3</translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation>Приховати список</translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Встановити пакетний файл</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Завантаження коментарів</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копіювати URL</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Прибрати</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Показати субтитри</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Показати коментарі</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Показати параметри медіа</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Завантажити частину мультимедіа</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Встановити</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Завантаження субтитрів</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>Сортувати за збільшенням дати</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>Сортувати за спаданням дати</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>Сортувати за лайками</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Встановити за замовчуванням</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Прибрати</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Виберіть файл плагіна</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Встановити папку завантаження</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Скидання</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation>Виберіть файл кукі</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Ім&apos;я веб-браузера для отримання куків</translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation>Шлях до файлу кукі</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Видалити все</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation>Хочете видалити вказаний файл?</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation>Хочете видалити вказану папку?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Так</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ні</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation>Хочете видалити всі файли та папки?</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Перейменувати текст</translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation>Перейменувати папку</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation>Хочете видалити вибрані елементи?</translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Вікно журналу</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Прибрати</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Приховати елементи керування</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Параметри списку:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копіювати URL</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Показати коментарі</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Показати всі оновлені</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Завантажити всі оновлені</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Управління підписками</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Кількість завантажених сторінок</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Завантаження інформації про відео</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Показати елементи керування</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Показати</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Приховати</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Це може тривати багато часу</translation>
    </message>
</context>
</TS>
